/*
 *  trtable.h - Tom Rettig's Library functions list.
 *
 *  by Alastair Dallas, Ralph Davis, Tom Rettig, and Leonard Zerman
 *
 *  Placed in the public domain by Tom Rettig Associates, 10/22/1990.
 */

/*
 * MINCONFIG is an example of how to configure trtable.h with a subset
 * of the full Tom Rettig Library.  Define MINCONFIG in trlib.c to
 * load only four functions: CMONTHN, ISPRINTER, RJUST, and TRVERS.
 */

/*
 * Every executable function in the table must be declared
 * here first. (note: functions may be declared in any order)
 *
 * This is what causes the linker to include the function's
 * object code from TRDBASE.LIB.
 */

int _tr_vers();
#ifndef MINCONFIG
int allocate();
int atlast();
int atnext();
int base();
int base10();
int biosattr();
int blank();
int boqtr();
int buffers();
int capfirst();
int ceiling();
int center();
int chrcount();
int chrfound();
int chrswap();
#endif
int cmonthn();
#ifndef MINCONFIG
int country();
int curdir();
int curdrive();
int dealloc();
int dec();
int decrypt();
int depdb();
int depsl();
int depvaldb();
int depvalsl();
int dirmake();
int dosvers();
int dtoss();
int effyield();
int empty();
int encrypt();
int eoq();
int eoqtr();
int expand();
int exponent();
int fact();
int files();
int fileread();
int filesize();
int filewrite();
int flr();
int hex();
int htoss();
int inctime();
int infinity();
int int3();
int isdrive();
int isdsdate();
int isfixed();
int isleap();
#endif
int isprinter();
#ifndef MINCONFIG
int iststime();
int lastday();
int lastdrive();
int leadchar();
int lines();
int ljust();
int lognbasx();
int logten();
int lptswap();
int makedate();
int maketime();
int mantissa();
int mem();
int mtoss();
int ntod();
int password();
int peekbyte();
int peekchar();
int peekdbl();
int peekint();
int peeklong();
int peekscr();
int peekstr();
int pokebyte();
int pokechar();
int pokedbl();
int pokeint();
int pokelong();
int pokescr();
int pokestr();
int prnstatus();
int prtsc();
int quarter();
int reg();
int restscr();
#endif
int retc();           /* do not remove */
int rjust();
#ifndef MINCONFIG
int root();
int savescr();
int separate();
int shutdown();
int soundex();
int sstod();
int sstoh();
int sstom();
int street();
int tabstrip();
int timestr();
int tomoney();
#endif
int trvers();         /* do not remove */
#ifndef MINCONFIG
int tr_cursor();
int tr_dosfunc();
int tr_fileattr();
int tr_list();
int tr_memdump();
int tr_offset();
int tr_rombios();
int tr_scroll();
int tr_segment();
int tstoh();
int tstom();
int tstos();
int wpstrip();
int wrap();
#endif

/* It is vital that the following list remain in alphabetical order. */   
 
struct tr_dt tr_vectors[] =
   {
      /* type checking for call with TYPE() */
      " C",          0,           0, "",     /* do not remove */
      " D",          0,           0, "",
      " L",          0,           0, "",     /* Must have preceding space */
      " N",          0,           0, "",     /* Last type = element 3 */
#ifndef MINCONFIG
      "ALLOCATE",    &allocate,   1, "N",
      "ATLAST",      &atlast,     2, "CC",
      "ATNEXT",      &atnext,     3, "CCN",
      "BASE",        &base,       2, "NN",
      "BASE10",      &base10,     2, "NC",
      "BIOSATTR",    &biosattr,   0, "",
      "BLANK",       &blank,      1, "V",
      "BOQTR",       &boqtr,      1, "D",
      "BUFFERS",     &buffers,    0, "",
      "CAPFIRST",    &capfirst,   1, "C",
      "CEILING",     &ceiling,    1, "N",
      "CENTER",      &center,     2, "CN",
      "CHRCOUNT",    &chrcount,   2, "CC", 
      "CHRFOUND",    &chrfound,   2, "CC",
      "CHRSWAP",     &chrswap,    3, "CCC",
#endif              
      "CMONTHN",     &cmonthn,    1, "N",
#ifndef MINCONFIG   
      "COUNTRY",     &country,    0, "", 
      "CURDIR",      &curdir,     1, "C",
      "CURDRIVE",    &curdrive,   0, "",
      "CURSOR",      &tr_cursor,  1, "C",
      "DEALLOC",     &dealloc,    1, "C",
      "DEC",         &dec,        1, "C",
      "DECRYPT",     &decrypt,    2, "CC",
      "DEPDB",       &depdb,      3, "NNN",
      "DEPSL",       &depsl,      4, "NNNN",
      "DEPVALDB",    &depvaldb,   3, "NNN",
      "DEPVALSL",    &depvalsl,   4, "NNNN",
      "DIRMAKE",     &dirmake,    1, "C",
      "DOSFUNC",     &tr_dosfunc, 2, "CN", 
      "DOSVERS",     &dosvers,    0, "",
      "DTOSS",       &dtoss,      1, "N",
      "EFFYIELD",    &effyield,   2, "NN",
      "EMPTY",       &empty,      1, "V",
      "ENCRYPT",     &encrypt,    2, "CC",
      "EOQ",         &eoq,        5, "NNNNN",
      "EOQTR",       &eoqtr,      1, "D",
      "EXPAND",      &expand,     2, "CN", 
      "EXPONENT",    &exponent,   1, "N",
      "FACT",        &fact,       1, "N",
      "FILEATTR",    &tr_fileattr,2, "CC",
      "FILEREAD",    &fileread,   1, "C",
      "FILES",       &files,      0, "",
      "FILESIZE",    &filesize,   1, "C",
      "FILEWRITE",   &filewrite,  2, "CC",
      "FLR",         &flr,        1, "N",
      "HEX",         &hex,        1, "N",
      "HTOSS",       &htoss,      1, "N",
      "INCTIME",     &inctime,    3, "NNN",
      "INFINITY",    &infinity,   0, "",
      "INT3",        &int3,       0, "", 
      "ISDRIVE",     &isdrive,    1, "C",
      "ISDSDATE",    &isdsdate,   1, "C",
      "ISFIXED",     &isfixed,    1, "C",
      "ISLEAP",      &isleap,     1, "C",
#endif              
      "ISPRINTER",   &isprinter,  0, "",
#ifndef MINCONFIG   
      "ISTSTIME",    &iststime,   1, "C", 
      "LASTDAY",     &lastday,    2, "NN",
      "LASTDRIVE",   &lastdrive,  0, "", 
      "LEADCHAR",    &leadchar,   2, "CC", 
      "LINES",       &lines,      2, "CN",
      "LISTLIB",     &tr_list,    0, "",
      "LJUST",       &ljust,      1, "C", 
      "LOGNBASX",    &lognbasx,   2, "NN",
      "LOGTEN",      &logten,     1, "N",
      "LPTSWAP",     &lptswap,    0, "",
      "MAKEDATE",    &makedate,   2, "CN",
      "MAKETIME",    &maketime,   1, "C",
      "MANTISSA",    &mantissa,   1, "N",
      "MEM",         &mem,        0, "",
      "MEMDUMP",     &tr_memdump, 1, "V",
      "MTOSS",       &mtoss,      1, "N",
      "NTOD",        &ntod,       3, "NNN",
      "OFF",         &tr_offset,  1, "V",
      "PASSWORD",    &password,   1, "C",
      "PEEKBYTE",    &peekbyte,   2, "CN",
      "PEEKCHAR",    &peekchar,   2, "CN",
      "PEEKDBL",     &peekdbl,    2, "CN",
      "PEEKINT",     &peekint,    2, "CN",
      "PEEKLONG",    &peeklong,   2, "CN",
      "PEEKSCR",     &peekscr,    2, "CN", 
      "PEEKSTR",     &peekstr,    2, "CN",
      "POKEBYTE",    &pokebyte,   3, "CNC",
      "POKECHAR",    &pokechar,   3, "CNC",
      "POKEDBL",     &pokedbl,    3, "CNN",
      "POKEINT",     &pokeint,    3, "CNN",
      "POKELONG",    &pokelong,   3, "CNN",
      "POKESCR",     &pokescr,    2, "CN",
      "POKESTR",     &pokestr,    3, "CNC",
      "PRNSTATUS",   &prnstatus,  0, "",
      "PRTSC",       &prtsc,      0, "",
      "QUARTER",     &quarter,    1, "D",
      "REG",         &reg,        1, "C",
      "RESTSCR",     &restscr,    1, "C",      /* from file   */
#endif              
      "RETC",        &retc,       1, "C",      /* do not remove */
      "RJUST",       &rjust,      1, "C",
#ifndef MINCONFIG   
      "ROMBIOS",     &tr_rombios, 3, "NCN", 
      "ROOT",        &root,       2, "NN",
      "SAVESCR",     &savescr,    1, "C",      /* to file   */
      "SCROLL",      &tr_scroll,  6, "NNNNNC",
      "SEG",         &tr_segment, 1, "V",
      "SEPARATE",    &separate,   1, "C",
      "SOUNDEX",     &soundex,    1, "C",
      "SSTOD",       &sstod,      1, "N",
      "SSTOH",       &sstoh,      1, "N",
      "SSTOM",       &sstom,      1, "N",
      "STREET",      &street,     1, "C",
      "TABSTRIP",    &tabstrip,   2, "CN",
      "TIMESTR",     &timestr,    1, "N",
      "TOMONEY",     &tomoney,    1, "N",
#endif              
      "TRVERS",      &_tr_vers,   0, "",     /* do not remove */
#ifndef MINCONFIG   
      "TSTOH",       &tstoh,      1, "C",
      "TSTOM",       &tstom,      1, "C",
      "TSTOS",       &tstos,      1, "C",
      "WPSTRIP",     &wpstrip,    2, "CN",
      "WRAP",        &wrap,       2, "CN",
#endif              
                  /* function returning pointer to int returning null */
      "",         (int (*)())0,   0, ""    /* do not remove */
   };

int numvecs = (sizeof(tr_vectors)/sizeof(tr_vectors[0])) - 1;

/* eof */
